@@ -42,7 +42,21 @@ def __validate_english_md(path, file):
         for image in re.findall('!\[[^\]]*\]\((.*?)\s*("(?:.*[^"])")?\s*\)', content):
             assert (path / image[0]).exists(), f"`{image[0]}` not found"
 
+        # validate that all devices in code activities are present in the config
         soup = BeautifulSoup(content, "html.parser")
+        docker_config_path = path / "docker-compose.yml"
+        with docker_config_path.open("r") as docker_compose_path:
+            docker_compose = docker_compose_path.read()
+            docker_compose = yaml.load(docker_compose, Loader=yaml.CLoader)
+            valid_devices = docker_compose["services"].keys()
+
+            for activity in soup.find_all("activity", {"type": "code"}):
+                activity_device = activity.attrs.get("device")
+                if activity_device not in valid_devices:
+                    raise ValidationException(
+                        f"Invalid device '{activity_device}' in code activity"
+                    )
+
         base_msg = "Invalid english.md:"
 
         # PAGES
@@ -132,7 +146,7 @@ def validate_file_format(path, file):
 
 
 @click.group()
-@click.version_option("0.4.2")
+@click.version_option("0.5.0")
 def content_tools():
     pass
 
